@@ -57,9 +57,9 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: TODO: Convert any text file into template
-our $VERSION = 'v0.4.1'; # VERSION
+our $VERSION = 'v0.5.0'; # VERSION
 
-extends 'Dist::Zilla::File::OnDisk';
+extends 'Dist::Zilla::File::InMemory';
 
 use overload '""' => sub {
     my ( $self ) = @_;
@@ -243,7 +243,7 @@ Dist::Zilla::Plugin::Templates::File - TODO: Convert any text file into template
 
 =head1 VERSION
 
-Version v0.4.1, released on 2015-09-19 18:06 UTC.
+Version v0.5.0, released on 2015-09-22 10:18 UTC.
 
 =head1 SYNOPSIS
 
